#
# spec file for package python-django-otp-webauthn
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-django-otp-webauthn
Version:        0.6.0
Release:        1.1
Summary:        FIDO2 WebAuthn support for django-otp
License:        BSD-3-Clause
URL:            None
Source:         https://files.pythonhosted.org/packages/source/d/django-otp-webauthn/django_otp_webauthn-%{version}.tar.gz
BuildRequires:  %{python_module Django >= 4.2}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 4.2
Requires:       python-django-otp >= 1.4
Requires:       python-djangorestframework >= 3.14
Requires:       python-webauthn >= 2.1.0
BuildArch:      noarch
%python_subpackages

%description
This package provides an implementation of [WebAuthn Passkeys](https://passkeys.dev/) for Django.
It is written as a plugin for the [Django OTP framework](https://github.com/django-otp/django-otp)
for multi-factor authentication. Under the hood, this package uses [py_webauth](https://github.com/duo-labs/py_webauthn/)
to handle all cryptographic operations.

%prep
%autosetup -p1 -n django_otp_webauthn-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# no unit tests to run, just some sandbox

%files %{python_files}
%{python_sitelib}/django_otp_webauthn
%{python_sitelib}/django_otp_webauthn-%{version}.dist-info

%changelog
* Fri May 23 2025 Dirk Müller <dmueller@suse.com>
- update to 0.6.0:
  * Add documentation for nearly all features and settings to the
    Sphinx documentation site
  * Add support for Related Origin Requests, a feature defined in
    the level 3 working draft of the WebAuthn specification. It
    makes simple, cross-domain sharing of Passkeys possible
  * Add support for redirecting after Passkey authentication by
    reading a `next` url parameter from the current view
  * Add support for Django 5.2 pending its final release
  * All Python code is now 100%% covered by tests
  * Browser automation tests using Playwright and Chromium have
    been added to ensure the JavaScript implementation works as
    expected
  * The API views provided now explicitly indicate they only
    render JSON, disabling the browsable API (see #55 and #56, by
    AlmerCarbonEquity)
  * Fixed an issue where the display name of a Passkey would have
    the username between parenthesis for users that have both an
    empty `first_name` and `last_name`.
  * **Noteworthy:** the way WebAuthn user handles are generated
    has been changed to make them more privacy-friendly. There
    should be no breaking backward-compatibility issues.
  * For context: these are used by the browser to identify if it
    already has a Passkey stored for a given user account.
  * After registering a new Passkey, users are now automatically
    marked as 'mfa verified' in the context of `django_otp.login`
  * The default JavaScript implementation is now built using Node
    22
  * The default JavaScript implementation for interacting with
    the browser api has been updated to use
    `@simplewebauthn/browser` v13.1.0
* Sat Aug 31 2024 Markéta Machová <mmachova@suse.com>
- Initial packaging (v0.4.0), needed by weblate
